@@ -1,5 +1,4 @@
 from PythUnity import Variables
-from PythUnity import Functions
 import copy
 import pygame
 import types
@@ -8,7 +7,6 @@ class Object:
     self.destroyed = False
     self.parent = None
     self.children = []
-    self.variables = {}
     self.image = None
     self.text = None
     self.color = None
@@ -16,7 +14,7 @@ class Object:
     if(type(image) is tuple):
       self.color = image
     elif(type(image) is String):
-      self.text = copy.deepcopy(image)
+      self.text = image
     else:
       self.image = image 
       ratio = image.get_size()
@@ -31,12 +29,6 @@ class Object:
       self.button = Button(onClick, onDrag, onClickOff, enableDragOff)
     else:
       self.button = None
-    Functions.AddObject(self)
-  #####
-  def __getitem__(self, i):
-    return self.children[i]
-  def __len__(self):
-    return len(self.children)
   #####
   def Decendants(self):
     Throw(self)
@@ -84,7 +76,6 @@ class Object:
     copied = copy.deepcopy(self)
     copied.index = len(parChildren)
     parChildren.append(copied)
-    copied.parent = self.parent
     copied.Move(self.index + 1)
     CopyUnHelp(self)
     CopyUnHelp(copied)
