@@ -14,4 +14,7 @@ global backgroundColor
 backgroundColor = (255, 255, 255)
 
 global mousePosition
-mousePosition = (0, 0)
\ No newline at end of file
+mousePosition = (0, 0)
+
+global screenRect
+screenRect = (800, 600)
\ No newline at end of file
